@@ -124,12 +124,15 @@ export const messages: { [messageId: string]: MessageType } = {
   createVmNetTableHeaderType: 'Device Type',
   createVmNetTableHeaderVnicProfile: 'vNic Profile',
   createVmNetUnknownVnicProfile: 'UNKNOWN',
+  createVmStorageBootableMessage: 'Only one disk can be bootable at a time. ',
   createVmStorageEditActions: 'Disk Actions',
   createVmStorageEmptyInfo: 'No Disks have been defined for this VM.',
   createVmStorageEmptyTitle: 'No Disks Defined',
+  createVmStorageNoEditBootableMessage: 'Disk "{diskName}", defined by the selected template, is set as bootable. This can only be changed after the VM has been created.',
   createVmStorageNoEditHelpMessage: 'This Disk is defined by your selected template and cannot be edited or deleted at creation.',
   createVmStorageSelectDiskType: 'Select a Disk Type',
   createVmStorageSelectStorageDomain: 'Select a Storage Domain',
+  createVmStorageTableHeaderBootable: 'Bootable',
   createVmStorageTableHeaderName: 'Disk Name',
   createVmStorageTableHeaderSize: 'Size',
   createVmStorageTableHeaderStorageDomain: 'Storage Domain',
@@ -186,15 +189,15 @@ export const messages: { [messageId: string]: MessageType } = {
   diskEditorBootableLabel: 'Bootable',
   diskEditorBootableChangeMessage: 'Only one disk can be bootable at a time. The bootable flag will be removed from "{diskName}" and placed on this disk.',
   diskEditorDiskDeletingTooltip: 'The disk is being deleted.',
-  diskEditorFormatCantChangeHelp: 'Disk type cannot be changed after it has been created.',
-  diskEditorFormatCreateHelp: 'Once you have selected a disk type, you will not be able to change it.',
-  diskEditorFormatLabel: 'Disk Type',
-  diskEditorFormatNotAvailable: 'N/A',
-  diskEditorFormatOptionRaw: {
+  diskEditorDiskTypeCantChangeHelp: 'Disk type cannot be changed after it has been created.',
+  diskEditorDiskTypeCreateHelp: 'Once you have selected a disk type, you will not be able to change it.',
+  diskEditorDiskTypeLabel: 'Disk Type',
+  diskEditorDiskTypeNotAvailable: 'N/A',
+  diskEditorDiskTypeOptionPre: {
     message: 'Preallocated',
     description: 'Select list option for raw / preallocated format disk images',
   },
-  diskEditorFormatOptionCow: {
+  diskEditorDiskTypeOptionThin: {
     message: 'Thin Provision',
     description: 'Select list option for qcow / thin provisioned format disk images',
   },
